SecurityException class

Exception thrown by RaspShield when running in SecurityMode.strict and a threat is detected.

Implemented types

Constructors

SecurityException(String message)
Creates a SecurityException with the given message.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Description of the security threat that was detected.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited