string_shield library

Classes

Deobfuscator
Provides runtime deobfuscation for strings that were obfuscated at compile time by the String Shield generator.
Obfuscate
Marks a string constant for compile-time obfuscation.
ObfuscateClass
Marks a class for compile-time string obfuscation.
StringShield
Singleton manager for runtime string deobfuscation.
StringShieldConfig
Configuration for the StringShield module.

Enums

ObfuscationStrategy
The strategy used to obfuscate a string at compile time.