Deobfuscator class
Provides runtime deobfuscation for strings that were obfuscated at compile time by the String Shield generator.
This class is used by generated code and generally should not be called directly by application code.
All methods are static and pure-Dart with zero external dependencies.
// Generated code calls:
final value = Deobfuscator.xor(
Uint8List.fromList([0x1a, 0x2b, 0x3c]),
Uint8List.fromList([0x5c, 0x4d, 0x6e]),
);
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
enhancedXor(
Uint8List data, Uint8List key, List< int> junkPositions) → String - Deobfuscates a string that was encrypted with enhanced XOR.
-
split(
List< Uint8List> chunks, List<int> order) → String - Deobfuscates a string that was split into chunks at compile time.
-
xor(
Uint8List data, Uint8List key) → String - Deobfuscates a string that was XOR-encrypted at compile time.