SecurityResult class
Result of a single security detection check
Constructors
-
SecurityResult({required bool isDetected, String? message, Map<
String, dynamic> ? additionalData}) -
Constructs a new SecurityResult instance
const
Properties
-
additionalData
→ Map<
String, dynamic> ? -
Optional key-value pairs with raw detection metrics
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDetected → bool
-
Indicates whether the security threat was detected
final
- message → String?
-
Optional message detailing the detection reason
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited