FlutterNeoShieldWeb class

Web platform stub for flutter_neo_shield.

All features (Log Shield, Clipboard Shield, Memory Shield, String Shield) work in pure Dart. This class only satisfies Flutter's web plugin registration.

Constructors

FlutterNeoShieldWeb()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void
Registers the web plugin (no-op — all features are pure Dart).